#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-L/usr/lib32"
XSLT_LIBS="-lxslt -L/usr/lib32 -lxml2 -lm "
XSLT_INCLUDEDIR="-I/usr/include"
MODULE_VERSION="xslt-1.1.32"
